@@ -87,6 +87,7 @@ export class MyStack extends cdk.Stack {
       // options: {
       //   extension: {
       //     layerVersionName: "tailscale-extension",
+      //     nodeTlsRejectUnauthorized: false, // Sets the NODE_TLS_REJECT_UNAUTHORIZED environment variable to '0'
       //   },
       //   lambda: {
       //     functionName: "tailscale-proxy",
@@ -135,6 +136,8 @@ When calling the Proxy, include the following headers to specify the target mach
 
 * `ts-target-ip`: The IP address of the Tailscale-connected machine/device.
 * `ts-target-port`: The port of the Tailscale-connected machine/device.
+* `ts-https`: OPTIONAL, if undefined, the default behaviour is to use https when the port is 443. If specified then it
+  will override the default behaviour.
 
 These `ts-` headers are removed before the request is forwarded to the target machine.
 
@@ -379,25 +382,42 @@ class TailscaleLambdaProxyProps:
 @jsii.data_type(
     jsii_type="tailscale-lambda-proxy.TailscaleLambdaProxyPropsLambdaOption",
     jsii_struct_bases=[],
-    name_mapping={"function_name": "functionName"},
+    name_mapping={
+        "function_name": "functionName",
+        "node_tls_reject_unauthorized": "nodeTlsRejectUnauthorized",
+    },
 )
 class TailscaleLambdaProxyPropsLambdaOption:
-    def __init__(self, *, function_name: typing.Optional[builtins.str] = None) -> None:
+    def __init__(
+        self,
+        *,
+        function_name: typing.Optional[builtins.str] = None,
+        node_tls_reject_unauthorized: typing.Optional[builtins.bool] = None,
+    ) -> None:
         '''
         :param function_name: 
+        :param node_tls_reject_unauthorized: 
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__dbc605245a7905e261f1f575b026f71eb19dfac71fcdbbb59b18468ecce4a759)
             check_type(argname="argument function_name", value=function_name, expected_type=type_hints["function_name"])
+            check_type(argname="argument node_tls_reject_unauthorized", value=node_tls_reject_unauthorized, expected_type=type_hints["node_tls_reject_unauthorized"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
         if function_name is not None:
             self._values["function_name"] = function_name
+        if node_tls_reject_unauthorized is not None:
+            self._values["node_tls_reject_unauthorized"] = node_tls_reject_unauthorized
 
     @builtins.property
     def function_name(self) -> typing.Optional[builtins.str]:
         result = self._values.get("function_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def node_tls_reject_unauthorized(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("node_tls_reject_unauthorized")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -496,6 +516,7 @@ def _typecheckingstub__b1db2d7dac4f0d91262bca503b92335b2c7da889dea02a4605b962b6c
 def _typecheckingstub__dbc605245a7905e261f1f575b026f71eb19dfac71fcdbbb59b18468ecce4a759(
     *,
     function_name: typing.Optional[builtins.str] = None,
+    node_tls_reject_unauthorized: typing.Optional[builtins.bool] = None,
 ) -> None:
     """Type checking stubs"""
     pass
